==> brunch-2.0.1.tgz: package/README.md <==
# Brunch

[![Join the chat at https://gitter.im/brunch/brunch](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/brunch/brunch?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

[![NPM](https://nodei.co/npm/brunch.png?compact=true)](https://nodei.co/npm/brunch/)  
[![NPM](https://nodei.co/npm-dl/brunch.png)](https://nodei.co/npm/brunch/)

> HTML5 applications made easy.

Fast front-end web app build tool with simple declarative config, seamless incremental compilation for rapid development, an opinionated pipeline and workflow, and core support for source maps

## First steps

Install the latest stable version: `npm install -g brunch`
(use `sudo` if necessary)

To install edge version (from github master branch): 
`npm install -g brunch/brunch`
or
`npm install -g https://github.com/brunch/brunch/tarball/master`

* Create your project: `brunch new`
* Continuously build it for development: `brunch watch [-s]`
* Prepare it for production: `brunch build -P`
* **[See Brunch documentation](https://github.com/brunch/brunch/tree/master/docs)**
* Check out the [Getting started guide](https://github.com/brunch/brunch-guide/blob/master/content/en/chapter01-whats-brunch.md)
* Follow us on Twitter: [@brunch](http://twitter.com/brunch)
* Ask questions on forum (or stack overflow): http://ost.io/@brunch/brunch
* Visit our site: [brunch.io](http://brunch.io).

## License
Brunch is released under the [MIT License](https://raw.github.com/brunch/brunch/master/LICENSE)

==> brunch-2.0.2.tgz: package/README.md <==
# Brunch

[![Join the chat at https://gitter.im/brunch/brunch](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/brunch/brunch?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

[![NPM](https://nodei.co/npm/brunch.png?compact=true)](https://nodei.co/npm/brunch/)  
[![NPM](https://nodei.co/npm-dl/brunch.png)](https://nodei.co/npm/brunch/)

> HTML5 applications made easy.

Fast front-end web app build tool with simple declarative config, seamless incremental compilation for rapid development, an opinionated pipeline and workflow, and core support for source maps

## First steps

Install the latest stable version: `npm install -g brunch`
(use `sudo` if necessary)

To install edge version (from github master branch): 
`npm install -g brunch/brunch`
or
`npm install -g https://github.com/brunch/brunch/tarball/master`

* Create your project: `brunch new`
* Continuously build it for development: `brunch watch [-s]`
* Prepare it for production: `brunch build -p`
* **[See Brunch documentation](https://github.com/brunch/brunch/tree/master/docs)**
* Check out the [Getting started guide](https://github.com/brunch/brunch-guide/blob/master/content/en/chapter01-whats-brunch.md)
* Follow us on Twitter: [@brunch](http://twitter.com/brunch)
* Ask questions on forum (or stack overflow): http://ost.io/@brunch/brunch
* Visit our site: [brunch.io](http://brunch.io).

## License
Brunch is released under the [MIT License](https://raw.github.com/brunch/brunch/master/LICENSE)
